@@ -101,7 +101,6 @@ ANY_ALL
 ANY_ALL_REV
 ANY_REV
 ATOMIC
-BEGIN_GROUP
 BIG_BITSET
 BIG_BITSET_REV
 BOUNDARY
@@ -137,6 +136,7 @@ SET
 SET_REV
 SMALL_BITSET
 SMALL_BITSET_REV
+START_GROUP
 START_OF_LINE
 START_OF_STRING
 STRING
